<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS language="pl" version="2.1">
<context>
    <name>AboutDlg</name>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
</context>
<context>
    <name>AddNewTorrentDialog</name>
    <message>
        <source>Category:</source>
        <translation>Kategoria:</translation>
    </message>
    <message>
        <source>Start torrent</source>
        <translation>Rozpocznij pobieranie</translation>
    </message>
    <message>
        <source>Skip hash check</source>
        <translation>Pomiń sprawdzanie danych</translation>
    </message>
    <message>
        <source>Create subfolder</source>
        <translation>Utwórz podfolder</translation>
    </message>
    <message>
        <source>Torrent Management Mode:</source>
        <translation>Tryb zarządzania torrentem:</translation>
    </message>
</context>
<context>
    <name>CategoryFilterModel</name>
    <message>
        <source>All</source>
        <translation>Wszystkie</translation>
    </message>
    <message>
        <source>Uncategorized</source>
        <translation>Bez kategorii</translation>
    </message>
</context>
<context>
    <name>CategoryFilterWidget</name>
    <message>
        <source>Add category...</source>
        <translation>Dodaj kategorię...</translation>
    </message>
    <message>
        <source>Remove category</source>
        <translation>Usuń kategorię</translation>
    </message>
    <message>
        <source>Remove unused categories</source>
        <translation>Usuń nieużywane kategorie</translation>
    </message>
    <message>
        <source>Resume torrents</source>
        <translation>Wznów torrenty</translation>
    </message>
    <message>
        <source>Pause torrents</source>
        <translation>Wstrzymaj torrenty</translation>
    </message>
    <message>
        <source>Delete torrents</source>
        <translation>Usuń torrenty</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nowa kategoria</translation>
    </message>
    <message>
        <source>Edit category...</source>
        <translation>Edytuj kategorię...</translation>
    </message>
</context>
<context>
    <name>HttpServer</name>
    <message>
        <source>Exit qBittorrent</source>
        <translation>Zakończ qBittorrent</translation>
    </message>
    <message>
        <source>Only one link per line</source>
        <translation>W jednym wierszu można podać tylko jeden odnośnik</translation>
    </message>
    <message>
        <source>Global upload rate limit must be greater than 0 or disabled.</source>
        <translation>Ogólny limit prędkości wysyłania musi być większy od 0 lub wyłączony.</translation>
    </message>
    <message>
        <source>Global download rate limit must be greater than 0 or disabled.</source>
        <translation>Ogólny limit prędkości pobierania musi być większy od 0 lub wyłączony.</translation>
    </message>
    <message>
        <source>Alternative upload rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatywny limit prędkości wysyłania musi być większy niż 0 albo wyłączony.</translation>
    </message>
    <message>
        <source>Alternative download rate limit must be greater than 0 or disabled.</source>
        <translation>Alternatywny limit prędkości pobierania musi być większy niż 0 albo wyłączony.</translation>
    </message>
    <message>
        <source>Maximum active downloads must be greater than -1.</source>
        <translation>Maksymalna liczba aktywnych pobierań musi być większa niż -1.</translation>
    </message>
    <message>
        <source>Maximum active uploads must be greater than -1.</source>
        <translation>Maksymalna liczba aktywnych wysyłań musi być większa niż -1.</translation>
    </message>
    <message>
        <source>Maximum active torrents must be greater than -1.</source>
        <translation>Maksymalna liczba aktywnych torrentów musi być większa niż -1.</translation>
    </message>
    <message>
        <source>Maximum number of connections limit must be greater than 0 or disabled.</source>
        <translation>Limit połączeń musi być większy od 0 lub wyłączony.</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent limit must be greater than 0 or disabled.</source>
        <translation>Limit połączeń dla pliku torrent musi być większy od 0 lub wyłączony.</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent limit must be greater than 0 or disabled.</source>
        <translation>Limit slotów wysyłania dla pliku torrent musi być większy od 0 lub wyłączony.</translation>
    </message>
    <message>
        <source>Unable to save program preferences, qBittorrent is probably unreachable.</source>
        <translation>Nie można zapisać ustawień, prawdopodobnie qBittorrent jest nieosiągalny.</translation>
    </message>
    <message>
        <source>IRC: #qbittorrent on Freenode</source>
        <translation>IRC: #qbittorrent w sieci Freenode</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Nieznany</translation>
    </message>
    <message>
        <source>Share ratio limit must be between 0 and 9998.</source>
        <translation>Limit współczynnika udziału musi zawierać się w przedziale między 0 a 9998.</translation>
    </message>
    <message>
        <source>Seeding time limit must be between 0 and 525600 minutes.</source>
        <translation>Limit czasu seedowania musi zawierać się w przedziale między 0 a 525600 minut.</translation>
    </message>
    <message>
        <source>The port used for incoming connections must be between 1 and 65535.</source>
        <translation>Port, na którym nasłuchiwane są połączenia przychodzące, musi być pomiędzy 1 a 65535.</translation>
    </message>
    <message>
        <source>The port used for the Web UI must be between 1 and 65535.</source>
        <translation>Port, na którym działa interfejs WWW, musi być pomiędzy 1 a 65535.</translation>
    </message>
    <message>
        <source>Unable to log in, qBittorrent is probably unreachable.</source>
        <translation>Nie można się zalogować, qBittorrent jest prawdopodobnie nieosiągalny.</translation>
    </message>
    <message>
        <source>Invalid Username or Password.</source>
        <translation>Nieprawidłowa nazwa użytkownika lub hasło.</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nazwa użytkownika</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Login</source>
        <translation>Login</translation>
    </message>
    <message>
        <source>Original authors</source>
        <translation>Pierwotni autorzy</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Zastosuj</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Dodaj</translation>
    </message>
    <message>
        <source>Upload Torrents</source>
        <comment>Upload torrent files to qBittorent using WebUI</comment>
        <translation>Wyślij torrenty</translation>
    </message>
    <message>
        <source>Save files to location:</source>
        <translation>Zapisz pliki w położeniu:</translation>
    </message>
    <message>
        <source>Cookie:</source>
        <translation>Ciasteczko:</translation>
    </message>
    <message>
        <source>Type folder here</source>
        <translation>Wpisz tutaj folder</translation>
    </message>
    <message>
        <source>More information</source>
        <translation>Więcej informacji</translation>
    </message>
    <message>
        <source>Information about certificates</source>
        <translation>Informacje o certyfikatach</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Ustaw położenie</translation>
    </message>
    <message>
        <source>Limit upload rate</source>
        <translation>Ogranicz prędkości wysyłania</translation>
    </message>
    <message>
        <source>Limit download rate</source>
        <translation>Ogranicz prędkości pobierania</translation>
    </message>
    <message>
        <source>Rename torrent</source>
        <translation>Zmień nazwę torrenta</translation>
    </message>
    <message>
        <source>Other...</source>
        <comment>Save Files to: Watch Folder / Default Folder / Other...</comment>
        <translation>Inne...</translation>
    </message>
    <message>
        <source>Monday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>poniedziałek</translation>
    </message>
    <message>
        <source>Tuesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>wtorek</translation>
    </message>
    <message>
        <source>Wednesday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>środa</translation>
    </message>
    <message>
        <source>Thursday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>czwartek</translation>
    </message>
    <message>
        <source>Friday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>piątek</translation>
    </message>
    <message>
        <source>Saturday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>sobota</translation>
    </message>
    <message>
        <source>Sunday</source>
        <comment>Schedule the use of alternative rate limits on ...</comment>
        <translation>niedziela</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Download Torrents from their URLs or Magnet links</source>
        <translation>Pobierz torrenty z ich adresów URL albo łączy Magnet</translation>
    </message>
    <message>
        <source>Upload local torrent</source>
        <translation>Wyślij lokalny plik torrent</translation>
    </message>
    <message>
        <source>Are you sure you want to delete the selected torrents from the transfer list?</source>
        <translation>Czy na pewno usunąć wybrane pliki torrent z listy transferów?</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Zapisz</translation>
    </message>
    <message>
        <source>qBittorrent client is not reachable</source>
        <translation>Klient qBittorrent jest nieosiągalny</translation>
    </message>
    <message>
        <source>Global number of upload slots limit must be greater than 0 or disabled.</source>
        <translation>Ogólna liczba limitu slotów wysyłania musi być większy od 0 lub wyłączona.</translation>
    </message>
    <message>
        <source>Invalid category name:\nPlease do not use any special characters in the category name.</source>
        <translation>Nieprawidłowa nazwa kategorii:\nNie należy używać żadnych znaków specjalnych w nazwie kategorii.</translation>
    </message>
    <message>
        <source>Unable to create category</source>
        <translation>Nie można utworzyć kategorii</translation>
    </message>
    <message>
        <source>Upload rate threshold must be greater than 0.</source>
        <translation>Próg prędkości przesyłania musi być większy niż 0.</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>Free space: %1</source>
        <translation>Wolne miejsce: %1</translation>
    </message>
    <message>
        <source>Torrent inactivity timer must be greater than 0.</source>
        <translation>Zegar bezczynności torrenta musi być większy niż 0.</translation>
    </message>
    <message>
        <source>Saving Management</source>
        <translation>Zarządzanie zapisywaniem</translation>
    </message>
    <message>
        <source>Download rate threshold must be greater than 0.</source>
        <translation>Próg prędkości pobierania musi być większy niż 0.</translation>
    </message>
    <message>
        <source>qBittorrent has been shutdown</source>
        <translation>qBittorrent został zamknięty</translation>
    </message>
    <message>
        <source>JavaScript Required! You must enable JavaScript for the Web UI to work properly</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Narzędzia</translation>
    </message>
    <message>
        <source>File</source>
        <translation>Plik</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Pomoc</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Widok</translation>
    </message>
    <message>
        <source>Options...</source>
        <translation>Opcje...</translation>
    </message>
    <message>
        <source>Resume</source>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Minimum Priority</source>
        <translation>Minimalny priorytet</translation>
    </message>
    <message>
        <source>Top Priority</source>
        <translation>Najwyższy priorytet</translation>
    </message>
    <message>
        <source>Decrease Priority</source>
        <translation>Zmniejsz priorytet</translation>
    </message>
    <message>
        <source>Increase Priority</source>
        <translation>Zwiększ priorytet</translation>
    </message>
    <message>
        <source>Top Toolbar</source>
        <translation>Górny pasek narzędziowy</translation>
    </message>
    <message>
        <source>Status Bar</source>
        <translation>Pasek stanu</translation>
    </message>
    <message>
        <source>Speed in Title Bar</source>
        <translation>Prędkość na pasku tytułu</translation>
    </message>
    <message>
        <source>Donate!</source>
        <translation>Wspomóż!</translation>
    </message>
    <message>
        <source>Resume All</source>
        <translation>Wznów wszystkie</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <source>About</source>
        <translation>O programie</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Pause All</source>
        <translation>Wstrzymaj wszystkie</translation>
    </message>
    <message>
        <source>Add Torrent File...</source>
        <translation>Dodaj plik torrent...</translation>
    </message>
    <message>
        <source>Documentation</source>
        <translation>Dokumentacja</translation>
    </message>
    <message>
        <source>Add Torrent Link...</source>
        <translation>Dodaj łącze torrenta...</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Tak</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nie</translation>
    </message>
    <message>
        <source>Global Upload Speed Limit</source>
        <translation>Ogólny limit wysyłania</translation>
    </message>
    <message>
        <source>Global Download Speed Limit</source>
        <translation>Ogólny limit pobierania</translation>
    </message>
    <message>
        <source>Are you sure you want to quit qBittorrent?</source>
        <translation>Czy na pewno chcesz zamknąć qBittorrent?</translation>
    </message>
    <message>
        <source>[D: %1, U: %2] qBittorrent %3</source>
        <comment>D = Download; U = Upload; %3 is qBittorrent version</comment>
        <translation>[P: %1, W: %2] qBittorrent %3</translation>
    </message>
    <message>
        <source>Alternative speed limits</source>
        <translation>Alternatywne limity prędkości</translation>
    </message>
    <message>
        <source>Search Engine</source>
        <translation>Wyszukiwarka</translation>
    </message>
    <message>
        <source>Filter torrent list...</source>
        <translation>Filtruj listę torrentów...</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Transfers</source>
        <translation>Transfery</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opcje</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Pobierane</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Połączenie</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Prędkość</translation>
    </message>
    <message>
        <source>BitTorrent</source>
        <translation>BitTorrent</translation>
    </message>
    <message>
        <source>Web UI</source>
        <translation>Interfejs WWW</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Język</translation>
    </message>
    <message>
        <source>User Interface Language:</source>
        <translation>Język interfejsu:</translation>
    </message>
    <message>
        <source>Email notification upon download completion</source>
        <translation>Wyślij e-mail po ukończeniu pobierania</translation>
    </message>
    <message>
        <source>Run external program on torrent completion</source>
        <translation>Uruchom zewnętrzny program po ukończeniu pobierania</translation>
    </message>
    <message>
        <source>IP Filtering</source>
        <translation>Filtrowanie IP</translation>
    </message>
    <message>
        <source>Schedule the use of alternative rate limits</source>
        <translation>Harmonogram użycia alternatywnych limitów prędkości</translation>
    </message>
    <message>
        <source>Torrent Queueing</source>
        <translation>Kolejkowanie torrentów</translation>
    </message>
    <message>
        <source>Seed torrents until their seeding time reaches</source>
        <translation>Seeduj torrenty do czasu, aż czas seedowania osiągnie</translation>
    </message>
    <message>
        <source>Automatically add these trackers to new downloads:</source>
        <translation>Automatycznie dodaj te trackery do nowych pobierań:</translation>
    </message>
    <message>
        <source>Web User Interface (Remote control)</source>
        <translation>Interfejs WWW (zdalne zarządzanie)</translation>
    </message>
    <message>
        <source>IP address:</source>
        <translation>Adres IP:</translation>
    </message>
    <message>
        <source>Server domains:</source>
        <translation>Domeny serwera:</translation>
    </message>
    <message>
        <source>Use HTTPS instead of HTTP</source>
        <translation>Używaj HTTPS zamiast HTTP</translation>
    </message>
    <message>
        <source>Bypass authentication for clients on localhost</source>
        <translation>Pomiń uwierzytelnianie dla klientów lokalnego hosta</translation>
    </message>
    <message>
        <source>Bypass authentication for clients in whitelisted IP subnets</source>
        <translation>Pomiń uwierzytelnianie dla klientów w podsieciach IP z białej listy</translation>
    </message>
    <message>
        <source>Update my dynamic domain name</source>
        <translation>Aktualizuj nazwę domeny dynamicznej</translation>
    </message>
    <message>
        <source>Keep incomplete torrents in:</source>
        <translation>Przechowuj niekompletne torrenty w:</translation>
    </message>
    <message>
        <source>Copy .torrent files to:</source>
        <translation>Kopiuj pliki .torrent do:</translation>
    </message>
    <message>
        <source>Copy .torrent files for finished downloads to:</source>
        <translation>Kopiuj pliki .torrent zakończonych pobierań do:</translation>
    </message>
    <message>
        <source>Pre-allocate disk space for all files</source>
        <translation>Rezerwuj miejsce na dysku dla wszystkich plików</translation>
    </message>
    <message>
        <source>Append .!qB extension to incomplete files</source>
        <translation>Dodaj rozszerzenie .!qB do niekompletnych plików</translation>
    </message>
    <message>
        <source>Automatically add torrents from:</source>
        <translation>Automatycznie dodawaj torrenty z:</translation>
    </message>
    <message>
        <source>SMTP server:</source>
        <translation>Serwer SMTP:</translation>
    </message>
    <message>
        <source>This server requires a secure connection (SSL)</source>
        <translation>Ten serwer wymaga bezpiecznego połączenia (SSL)</translation>
    </message>
    <message>
        <source>Authentication</source>
        <translation>Uwierzytelnianie</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Nazwa użytkownika:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Hasło:</translation>
    </message>
    <message>
        <source>Enabled protocol:</source>
        <translation>Włącz protokół:</translation>
    </message>
    <message>
        <source>TCP and μTP</source>
        <translation>TCP oraz μTP</translation>
    </message>
    <message>
        <source>Listening Port</source>
        <translation>Port nasłuchu</translation>
    </message>
    <message>
        <source>Port used for incoming connections:</source>
        <translation>Port dla połączeń przychodzących:</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP port forwarding from my router</source>
        <translation>Używaj UPnP / NAT-PMP do przekierowania portów na moim routerze</translation>
    </message>
    <message>
        <source>Use different port on each startup</source>
        <translation>Używaj innego portu przy każdym uruchomieniu</translation>
    </message>
    <message>
        <source>Connections Limits</source>
        <translation>Limit połączeń</translation>
    </message>
    <message>
        <source>Maximum number of connections per torrent:</source>
        <translation>Maksymalna liczba połączeń na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of connections:</source>
        <translation>Maksymalna liczba połączeń:</translation>
    </message>
    <message>
        <source>Maximum number of upload slots per torrent:</source>
        <translation>Maksymalna liczba slotów wysyłania na torrent:</translation>
    </message>
    <message>
        <source>Global maximum number of upload slots:</source>
        <translation>Maksymalna liczba slotów wysyłania:</translation>
    </message>
    <message>
        <source>Proxy Server</source>
        <translation>Serwer proxy</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Typ:</translation>
    </message>
    <message>
        <source>(None)</source>
        <translation>(Żaden)</translation>
    </message>
    <message>
        <source>SOCKS4</source>
        <translation>SOCKS4</translation>
    </message>
    <message>
        <source>SOCKS5</source>
        <translation>SOCKS5</translation>
    </message>
    <message>
        <source>HTTP</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Host:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Port:</translation>
    </message>
    <message>
        <source>Use proxy for peer connections</source>
        <translation>Używaj proxy do połączeń z partnerami</translation>
    </message>
    <message>
        <source>Disable connections not supported by proxies</source>
        <translation>Wyłącz połączenia nieobsługiwane przez proxy</translation>
    </message>
    <message>
        <source>Use proxy only for torrents</source>
        <translation>Używaj proxy tylko dla torrentów</translation>
    </message>
    <message>
        <source>Filter path (.dat, .p2p, .p2b):</source>
        <translation>Ścieżka do pliku filtra (.dat, .p2p, .p2b):</translation>
    </message>
    <message>
        <source>Manually banned IP addresses...</source>
        <translation>Ręcznie zablokowane adresy IP...</translation>
    </message>
    <message>
        <source>Apply to trackers</source>
        <translation>Zastosuj do trackerów</translation>
    </message>
    <message>
        <source>Global Rate Limits</source>
        <translation>Ogólne limity prędkości</translation>
    </message>
    <message>
        <source>Upload:</source>
        <translation>Wysyłanie:</translation>
    </message>
    <message>
        <source>Download:</source>
        <translation>Pobieranie:</translation>
    </message>
    <message>
        <source>Alternative Rate Limits</source>
        <translation>Alternatywne limity prędkości</translation>
    </message>
    <message>
        <source>From:</source>
        <extracomment>from (time1 to time2)</extracomment>
        <translation>Od:</translation>
    </message>
    <message>
        <source>To:</source>
        <extracomment>time1 to time2</extracomment>
        <translation>Do:</translation>
    </message>
    <message>
        <source>When:</source>
        <translation>Kiedy:</translation>
    </message>
    <message>
        <source>Every day</source>
        <translation>Codziennie</translation>
    </message>
    <message>
        <source>Weekdays</source>
        <translation>Dni robocze</translation>
    </message>
    <message>
        <source>Weekends</source>
        <translation>Weekendy</translation>
    </message>
    <message>
        <source>Rate Limits Settings</source>
        <translation>Ustawienia limitów prędkości</translation>
    </message>
    <message>
        <source>Apply rate limit to transport overhead</source>
        <translation>Stosuj limity prędkości do transferów z narzutem</translation>
    </message>
    <message>
        <source>Apply rate limit to µTP protocol</source>
        <translation>Stosuj limity prędkości do protokołu µTP</translation>
    </message>
    <message>
        <source>Privacy</source>
        <translation>Prywatność</translation>
    </message>
    <message>
        <source>Enable DHT (decentralized network) to find more peers</source>
        <translation>Włącz sieć DHT (sieć rozproszona), aby odnależć więcej partnerów</translation>
    </message>
    <message>
        <source>Enable Peer Exchange (PeX) to find more peers</source>
        <translation>Włącz wymianę partnerów (PeX), aby odnależć więcej partnerów</translation>
    </message>
    <message>
        <source>Enable Local Peer Discovery to find more peers</source>
        <translation>Włącz wykrywanie partnerów w sieci lokalnej, aby znaleźć więcej partnerów</translation>
    </message>
    <message>
        <source>Encryption mode:</source>
        <translation>Tryb szyfrowania:</translation>
    </message>
    <message>
        <source>Prefer encryption</source>
        <translation>Preferuj szyfrowanie</translation>
    </message>
    <message>
        <source>Require encryption</source>
        <translation>Wymagaj szyfrowania</translation>
    </message>
    <message>
        <source>Disable encryption</source>
        <translation>Wyłącz szyfrowanie</translation>
    </message>
    <message>
        <source>Enable anonymous mode</source>
        <translation>Włącz tryb anonimowy</translation>
    </message>
    <message>
        <source>Maximum active downloads:</source>
        <translation>Maksymalna liczba aktywnych pobierań:</translation>
    </message>
    <message>
        <source>Maximum active uploads:</source>
        <translation>Maksymalna liczba aktywnych wysyłań:</translation>
    </message>
    <message>
        <source>Maximum active torrents:</source>
        <translation>Maksymalna liczba aktywnych torrentów:</translation>
    </message>
    <message>
        <source>Do not count slow torrents in these limits</source>
        <translation>Nie wliczaj powolnych torrentów do tych limitów</translation>
    </message>
    <message>
        <source>Share Ratio Limiting</source>
        <translation>Limitowanie współczynnika udziału</translation>
    </message>
    <message>
        <source>Seed torrents until their ratio reaches</source>
        <translation>Seeduj torrenty, aż współczynnik udziału osiągnie</translation>
    </message>
    <message>
        <source>then</source>
        <translation>następnie</translation>
    </message>
    <message>
        <source>Pause them</source>
        <translation>Wstrzymaj je</translation>
    </message>
    <message>
        <source>Remove them</source>
        <translation>Usuń je</translation>
    </message>
    <message>
        <source>Use UPnP / NAT-PMP to forward the port from my router</source>
        <translation>Używaj UPnP / NAT-PMP do przekierowania portów na moim routerze</translation>
    </message>
    <message>
        <source>Certificate:</source>
        <translation>Certyfikat:</translation>
    </message>
    <message>
        <source>Key:</source>
        <translation>Klucz:</translation>
    </message>
    <message>
        <source>Register</source>
        <translation>Zarejestruj</translation>
    </message>
    <message>
        <source>Domain name:</source>
        <translation>Nazwa domeny:</translation>
    </message>
    <message>
        <source>Supported parameters (case sensitive):</source>
        <translation>Obsługiwane parametry (z uwzględnieniem wielkości liter):</translation>
    </message>
    <message>
        <source>%N: Torrent name</source>
        <translation>%N: Nazwa torrenta</translation>
    </message>
    <message>
        <source>%L: Category</source>
        <translation>%L: Kategoria</translation>
    </message>
    <message>
        <source>%G: Tags (seperated by comma)</source>
        <translation type="vanished">%G: Znaczniki (oddzielone przecinkiem)</translation>
    </message>
    <message>
        <source>%F: Content path (same as root path for multifile torrent)</source>
        <translation>%F: Ścieżka zawartości (taka sama, jak główna ścieżka dla wieloplikowych torrentów)</translation>
    </message>
    <message>
        <source>%R: Root path (first torrent subdirectory path)</source>
        <translation>%R: Ścieżka główna (pierwsza ścieżka podkatalogu torrenta)</translation>
    </message>
    <message>
        <source>%D: Save path</source>
        <translation>%D: Ścieżka zapisu</translation>
    </message>
    <message>
        <source>%C: Number of files</source>
        <translation>%C: Liczba plików</translation>
    </message>
    <message>
        <source>%Z: Torrent size (bytes)</source>
        <translation>%Z: Rozmiar torrenta (w bajtach)</translation>
    </message>
    <message>
        <source>%T: Current tracker</source>
        <translation>%T: Bieżący tracker</translation>
    </message>
    <message>
        <source>%I: Info hash</source>
        <translation>%I: Info hash</translation>
    </message>
    <message>
        <source>Tip: Encapsulate parameter with quotation marks to avoid text being cut off at whitespace (e.g., "%N")</source>
        <translation>Wskazówka: otocz parametr cudzysłowem, aby uniknąć odcięcia tekstu (np. "%N")</translation>
    </message>
    <message>
        <source>The Web UI username must be at least 3 characters long.</source>
        <translation>Nazwa użytkownika interfejsu WWW musi składać się z co najmniej 3 znaków.</translation>
    </message>
    <message>
        <source>The Web UI password must be at least 6 characters long.</source>
        <translation>Hasło interfejsu WWW musi składać się z co najmniej 6 znaków.</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minut</translation>
    </message>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
    <message>
        <source>Enable clickjacking protection</source>
        <translation>Włącz ochronę przed porywaniem kliknięć</translation>
    </message>
    <message>
        <source>Enable Cross-Site Request Forgery (CSRF) protection</source>
        <translation>Włącz ochronę przed Cross-Site Request Forgery (CSRF)</translation>
    </message>
    <message>
        <source>Delete .torrent files afterwards</source>
        <translation>Potem usuń pliki .torrent</translation>
    </message>
    <message>
        <source>Download rate threshold:</source>
        <translation>Próg prędkości pobierania:</translation>
    </message>
    <message>
        <source>Upload rate threshold:</source>
        <translation>Próg prędkości wysyłania:</translation>
    </message>
    <message>
        <source>Change current password</source>
        <translation>Zmień obecne hasło</translation>
    </message>
    <message>
        <source>Automatic</source>
        <translation>Automatyczny</translation>
    </message>
    <message>
        <source>Use alternative Web UI</source>
        <translation>Używaj alternatywnego interfejsu WWW</translation>
    </message>
    <message>
        <source>Default Save Path:</source>
        <translation>Domyślna ścieżka zapisu:</translation>
    </message>
    <message>
        <source>The alternative Web UI files location cannot be blank.</source>
        <translation>Lokalizacja plików alternatywnego interfejsu WWW nie może być pusta.</translation>
    </message>
    <message>
        <source>Do not start the download automatically</source>
        <translation>Nie uruchamiaj automatycznie pobierań</translation>
    </message>
    <message>
        <source>Switch torrent to Manual Mode</source>
        <translation>Przełącz torrent na tryb ręczny</translation>
    </message>
    <message>
        <source>When Torrent Category changed:</source>
        <translation>Gdy zmieniono kategorię torrenta:</translation>
    </message>
    <message>
        <source>Relocate affected torrents</source>
        <translation>Przenieś zależne torrenty</translation>
    </message>
    <message>
        <source>Apply rate limit to peers on LAN</source>
        <translation>Stosuj limity prędkości do partnerów w LAN</translation>
    </message>
    <message>
        <source>0 means unlimited</source>
        <translation>0 oznacza nieograniczoną liczbę</translation>
    </message>
    <message>
        <source>Relocate torrent</source>
        <translation>Przenieś torrent</translation>
    </message>
    <message>
        <source>When Default Save Path changed:</source>
        <translation>Gdy zmieniono domyślną ścieżkę zapisu:</translation>
    </message>
    <message>
        <source>Enable Host header validation</source>
        <translation>Włącz sprawdzanie nagłówków hosta</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Bezpieczeństwo</translation>
    </message>
    <message>
        <source>When Category Save Path changed:</source>
        <translation>Gdy zmieniono ścieżkę zapisu kategorii:</translation>
    </message>
    <message>
        <source>Create subfolder for torrents with multiple files</source>
        <translation>Utwórz podfolder dla torrentów z wieloma plikami</translation>
    </message>
    <message>
        <source>seconds</source>
        <translation>sekund</translation>
    </message>
    <message>
        <source>Switch affected torrents to Manual Mode</source>
        <translation>Przełącz zależne torrenty na tryb ręczny</translation>
    </message>
    <message>
        <source>Files location:</source>
        <translation>Położenie plików:</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Ręczny</translation>
    </message>
    <message>
        <source>Torrent inactivity timer:</source>
        <translation>Zegar bezczynności torrenta:</translation>
    </message>
    <message>
        <source>Default Torrent Management Mode:</source>
        <translation>Domyślny tryb zarządzania torrentem:</translation>
    </message>
    <message>
        <source>When adding a torrent</source>
        <translation>Podczas dodawania torrenta</translation>
    </message>
    <message>
        <source>%G: Tags (separated by comma)</source>
        <translation type="unfinished" />
    </message>
</context>
<context>
    <name>PeerListWidget</name>
    <message>
        <source>IP</source>
        <translation>Adres IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <source>Flags</source>
        <translation>Flagi</translation>
    </message>
    <message>
        <source>Connection</source>
        <translation>Połączenie</translation>
    </message>
    <message>
        <source>Client</source>
        <comment>i.e.: Client application</comment>
        <translation>Klient</translation>
    </message>
    <message>
        <source>Progress</source>
        <comment>i.e: % downloaded</comment>
        <translation>Postęp</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>i.e: total data downloaded</comment>
        <translation>Pobrano</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>i.e: total data uploaded</comment>
        <translation>Wysłano</translation>
    </message>
    <message>
        <source>Relevance</source>
        <comment>i.e: How relevant this peer is to us. How many pieces it has that we don't.</comment>
        <translation>Trafność</translation>
    </message>
    <message>
        <source>Files</source>
        <comment>i.e. files that are being downloaded right now</comment>
        <translation>Pliki</translation>
    </message>
    <message>
        <source>Country</source>
        <translation>Kraj</translation>
    </message>
</context>
<context>
    <name>PropListDelegate</name>
    <message>
        <source>Normal</source>
        <comment>Normal (priority)</comment>
        <translation>Normalny</translation>
    </message>
    <message>
        <source>High</source>
        <comment>High (priority)</comment>
        <translation>Wysoki</translation>
    </message>
    <message>
        <source>Maximum</source>
        <comment>Maximum (priority)</comment>
        <translation>Maksymalny</translation>
    </message>
</context>
<context>
    <name>PropTabBar</name>
    <message>
        <source>General</source>
        <translation>Główne</translation>
    </message>
    <message>
        <source>Trackers</source>
        <translation>Trackery</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Partnerzy</translation>
    </message>
    <message>
        <source>HTTP Sources</source>
        <translation>Źródła HTTP</translation>
    </message>
    <message>
        <source>Content</source>
        <translation>Zawartość</translation>
    </message>
</context>
<context>
    <name>PropertiesWidget</name>
    <message>
        <source>Downloaded:</source>
        <translation>Pobrano:</translation>
    </message>
    <message>
        <source>Transfer</source>
        <translation>Transfer</translation>
    </message>
    <message>
        <source>Time Active:</source>
        <extracomment>Time (duration) the torrent is active (not paused)</extracomment>
        <translation>Aktywny przez:</translation>
    </message>
    <message>
        <source>ETA:</source>
        <translation>ETA:</translation>
    </message>
    <message>
        <source>Uploaded:</source>
        <translation>Wysłano:</translation>
    </message>
    <message>
        <source>Seeds:</source>
        <translation>Seedy:</translation>
    </message>
    <message>
        <source>Download Speed:</source>
        <translation>Prędkość pobierania:</translation>
    </message>
    <message>
        <source>Upload Speed:</source>
        <translation>Prędkość wysyłania:</translation>
    </message>
    <message>
        <source>Peers:</source>
        <translation>Partnerzy:</translation>
    </message>
    <message>
        <source>Download Limit:</source>
        <translation>Limit pobierania:</translation>
    </message>
    <message>
        <source>Upload Limit:</source>
        <translation>Limit wysyłania:</translation>
    </message>
    <message>
        <source>Wasted:</source>
        <translation>Odrzucono:</translation>
    </message>
    <message>
        <source>Connections:</source>
        <translation>Połączeń:</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Informacje</translation>
    </message>
    <message>
        <source>Comment:</source>
        <translation>Komentarz:</translation>
    </message>
    <message>
        <source>Share Ratio:</source>
        <translation>Współczynnik udziału:</translation>
    </message>
    <message>
        <source>Reannounce In:</source>
        <translation>Rozgłoszenie za:</translation>
    </message>
    <message>
        <source>Last Seen Complete:</source>
        <translation>Ostatni raz widziany kompletny:</translation>
    </message>
    <message>
        <source>Total Size:</source>
        <translation>Całkowity rozmiar:</translation>
    </message>
    <message>
        <source>Pieces:</source>
        <translation>Części:</translation>
    </message>
    <message>
        <source>Created By:</source>
        <translation>Utworzony przez:</translation>
    </message>
    <message>
        <source>Added On:</source>
        <translation>Dodano:</translation>
    </message>
    <message>
        <source>Completed On:</source>
        <translation>Ukończono:</translation>
    </message>
    <message>
        <source>Created On:</source>
        <translation>Utworzono:</translation>
    </message>
    <message>
        <source>Torrent Hash:</source>
        <translation>Hash torrenta:</translation>
    </message>
    <message>
        <source>Save Path:</source>
        <translation>Ścieżka zapisu:</translation>
    </message>
    <message>
        <source>Never</source>
        <translation>Nigdy</translation>
    </message>
    <message>
        <source>%1 x %2 (have %3)</source>
        <comment>(torrent pieces) eg 152 x 4MB (have 25)</comment>
        <translation>%1 x %2 (ma %3)</translation>
    </message>
    <message>
        <source>%1 (%2 this session)</source>
        <translation>%1 (w tej sesji %2)</translation>
    </message>
    <message>
        <source>%1 (%2 max)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 max)</comment>
        <translation>%1 (maksymalnie %2)</translation>
    </message>
    <message>
        <source>%1 (%2 total)</source>
        <comment>%1 and %2 are numbers, e.g. 3 (10 total)</comment>
        <translation>%1 (całkowicie %2)</translation>
    </message>
    <message>
        <source>%1 (%2 avg.)</source>
        <comment>%1 and %2 are speed rates, e.g. 200KiB/s (100KiB/s avg.)</comment>
        <translation>%1 (średnio %2)</translation>
    </message>
    <message>
        <source>Download limit:</source>
        <translation>Limit pobierania:</translation>
    </message>
    <message>
        <source>Upload limit:</source>
        <translation>Limit wysyłania:</translation>
    </message>
</context>
<context>
    <name>ScanFoldersModel</name>
    <message>
        <source>Monitored Folder</source>
        <translation>Monitorowany katalog</translation>
    </message>
    <message>
        <source>Override Save Location</source>
        <translation>Zastąp miejsce zapisu</translation>
    </message>
    <message>
        <source>Monitored folder</source>
        <translation>Monitorowany katalog</translation>
    </message>
    <message>
        <source>Default save location</source>
        <translation>Domyślne miejsce zapisu</translation>
    </message>
</context>
<context>
    <name>SpeedLimitDialog</name>
    <message>
        <source>KiB/s</source>
        <translation>KiB/s</translation>
    </message>
</context>
<context>
    <name>StatsDialog</name>
    <message>
        <source>Statistics</source>
        <translation>Statystyki</translation>
    </message>
    <message>
        <source>User statistics</source>
        <translation>Statystyki użytkownika</translation>
    </message>
    <message>
        <source>Cache statistics</source>
        <translation>Statystyki cache</translation>
    </message>
    <message>
        <source>Read cache hits:</source>
        <translation>Odsłony pamięci podręcznej odczytu:</translation>
    </message>
    <message>
        <source>Average time in queue:</source>
        <translation>Średni czas w kolejce:</translation>
    </message>
    <message>
        <source>Connected peers:</source>
        <translation>Połączeni partnerzy:</translation>
    </message>
    <message>
        <source>All-time share ratio:</source>
        <translation>Współczynnik udziału absolutny:</translation>
    </message>
    <message>
        <source>All-time download:</source>
        <translation>Pobieranie absolutne: </translation>
    </message>
    <message>
        <source>Session waste:</source>
        <translation>Strata sesji:</translation>
    </message>
    <message>
        <source>All-time upload:</source>
        <translation>Wysyłanie absolutne: </translation>
    </message>
    <message>
        <source>Total buffer size:</source>
        <translation>Całość rozmiaru bufora:</translation>
    </message>
    <message>
        <source>Performance statistics</source>
        <translation>Statystyki wydajności</translation>
    </message>
    <message>
        <source>Queued I/O jobs:</source>
        <translation>Zadania we/wy w kolejce:</translation>
    </message>
    <message>
        <source>Write cache overload:</source>
        <translation>Przepełnienie pamięci podręcznej zapisu:</translation>
    </message>
    <message>
        <source>Read cache overload:</source>
        <translation>Przepełnienie pamięci podręcznej odczytu:</translation>
    </message>
    <message>
        <source>Total queued size:</source>
        <translation>Całkowity rozmiar kolejki:</translation>
    </message>
</context>
<context>
    <name>StatusBar</name>
    <message>
        <source>DHT: %1 nodes</source>
        <translation>Węzły DHT: %1</translation>
    </message>
</context>
<context>
    <name>StatusFilterWidget</name>
    <message>
        <source>All (0)</source>
        <comment>this is for the status filter</comment>
        <translation>Wszystkie (0)</translation>
    </message>
    <message>
        <source>Downloading (0)</source>
        <translation>Pobierane (0)</translation>
    </message>
    <message>
        <source>Seeding (0)</source>
        <translation>Seedowane (0)</translation>
    </message>
    <message>
        <source>Completed (0)</source>
        <translation>Ukończone (0)</translation>
    </message>
    <message>
        <source>Resumed (0)</source>
        <translation>Wznowione (0)</translation>
    </message>
    <message>
        <source>Paused (0)</source>
        <translation>Wstrzymane (0)</translation>
    </message>
    <message>
        <source>Active (0)</source>
        <translation>Aktywne (0)</translation>
    </message>
    <message>
        <source>Inactive (0)</source>
        <translation>Nieaktywne (0)</translation>
    </message>
    <message>
        <source>Errored (0)</source>
        <translation>Błędne (0)</translation>
    </message>
    <message>
        <source>All (%1)</source>
        <translation>Wszystkie (%1)</translation>
    </message>
    <message>
        <source>Downloading (%1)</source>
        <translation>Pobierane (%1)</translation>
    </message>
    <message>
        <source>Seeding (%1)</source>
        <translation>Seedowane (%1)</translation>
    </message>
    <message>
        <source>Completed (%1)</source>
        <translation>Ukończone (%1)</translation>
    </message>
    <message>
        <source>Paused (%1)</source>
        <translation>Wstrzymane (%1)</translation>
    </message>
    <message>
        <source>Resumed (%1)</source>
        <translation>Wznowione (%1)</translation>
    </message>
    <message>
        <source>Active (%1)</source>
        <translation>Aktywne (%1)</translation>
    </message>
    <message>
        <source>Inactive (%1)</source>
        <translation>Nieaktywne (%1)</translation>
    </message>
    <message>
        <source>Errored (%1)</source>
        <translation>Błędne (%1)</translation>
    </message>
</context>
<context>
    <name>TorrentContentModel</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Postęp</translation>
    </message>
    <message>
        <source>Download Priority</source>
        <translation>Priorytet pobierania</translation>
    </message>
    <message>
        <source>Remaining</source>
        <translation>Pozostało</translation>
    </message>
    <message>
        <source>Availability</source>
        <translation>Dostępność</translation>
    </message>
</context>
<context>
    <name>TransferListModel</name>
    <message>
        <source>Name</source>
        <comment>i.e: torrent name</comment>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Size</source>
        <comment>i.e: torrent size</comment>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Done</source>
        <comment>% Done</comment>
        <translation>Ukończono</translation>
    </message>
    <message>
        <source>Status</source>
        <comment>Torrent status (e.g. downloading, seeding, paused)</comment>
        <translation>Status</translation>
    </message>
    <message>
        <source>Seeds</source>
        <comment>i.e. full sources (often untranslated)</comment>
        <translation>Seedy</translation>
    </message>
    <message>
        <source>Peers</source>
        <comment>i.e. partial sources (often untranslated)</comment>
        <translation>Partnerzy</translation>
    </message>
    <message>
        <source>Down Speed</source>
        <comment>i.e: Download speed</comment>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Up Speed</source>
        <comment>i.e: Upload speed</comment>
        <translation>Wysyłanie</translation>
    </message>
    <message>
        <source>Ratio</source>
        <comment>Share ratio</comment>
        <translation>Udział</translation>
    </message>
    <message>
        <source>ETA</source>
        <comment>i.e: Estimated Time of Arrival / Time left</comment>
        <translation>ETA</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>Tags</source>
        <translation>Znaczniki</translation>
    </message>
    <message>
        <source>Added On</source>
        <comment>Torrent was added to transfer list on 01/01/2010 08:00</comment>
        <translation>Dodano</translation>
    </message>
    <message>
        <source>Completed On</source>
        <comment>Torrent was completed on 01/01/2010 08:00</comment>
        <translation>Ukończono</translation>
    </message>
    <message>
        <source>Tracker</source>
        <translation>Tracker</translation>
    </message>
    <message>
        <source>Down Limit</source>
        <comment>i.e: Download limit</comment>
        <translation>Limit pobierania</translation>
    </message>
    <message>
        <source>Up Limit</source>
        <comment>i.e: Upload limit</comment>
        <translation>Limit wysyłania</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <comment>Amount of data downloaded (e.g. in MB)</comment>
        <translation>Pobrano</translation>
    </message>
    <message>
        <source>Uploaded</source>
        <comment>Amount of data uploaded (e.g. in MB)</comment>
        <translation>Wysłano</translation>
    </message>
    <message>
        <source>Session Download</source>
        <comment>Amount of data downloaded since program open (e.g. in MB)</comment>
        <translation>Pobrane w sesji</translation>
    </message>
    <message>
        <source>Session Upload</source>
        <comment>Amount of data uploaded since program open (e.g. in MB)</comment>
        <translation>Wysłane w sesji</translation>
    </message>
    <message>
        <source>Remaining</source>
        <comment>Amount of data left to download (e.g. in MB)</comment>
        <translation>Pozostało</translation>
    </message>
    <message>
        <source>Time Active</source>
        <comment>Time (duration) the torrent is active (not paused)</comment>
        <translation>Aktywny przez</translation>
    </message>
    <message>
        <source>Save path</source>
        <comment>Torrent save path</comment>
        <translation>Katalog docelowy</translation>
    </message>
    <message>
        <source>Completed</source>
        <comment>Amount of data completed (e.g. in MB)</comment>
        <translation>Ukończone</translation>
    </message>
    <message>
        <source>Ratio Limit</source>
        <comment>Upload share ratio limit</comment>
        <translation>Limit współczynnika udziału</translation>
    </message>
    <message>
        <source>Last Seen Complete</source>
        <comment>Indicates the time when the torrent was last seen complete/whole</comment>
        <translation>Ostatni raz widziany kompletny</translation>
    </message>
    <message>
        <source>Last Activity</source>
        <comment>Time passed since a chunk was downloaded/uploaded</comment>
        <translation>Ostatnia aktywność</translation>
    </message>
    <message>
        <source>Total Size</source>
        <comment>i.e. Size including unwanted data</comment>
        <translation>Całkowity rozmiar</translation>
    </message>
</context>
<context>
    <name>TrackerListWidget</name>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Peers</source>
        <translation>Partnerzy</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Komunikat</translation>
    </message>
    <message>
        <source>Downloaded</source>
        <translation>Pobrany</translation>
    </message>
    <message>
        <source>Tracker URL:</source>
        <translation>Adres URL trackera:</translation>
    </message>
    <message>
        <source>Updating...</source>
        <translation>Aktualizowanie...</translation>
    </message>
    <message>
        <source>Working</source>
        <translation>Działa</translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation>Wyłączone</translation>
    </message>
    <message>
        <source>Not contacted yet</source>
        <translation>Niesprawdzony</translation>
    </message>
    <message>
        <source>#</source>
        <translation>#</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>Nie dotyczy</translation>
    </message>
    <message>
        <source>Seeds</source>
        <translation>Seedy</translation>
    </message>
    <message>
        <source>Not working</source>
        <translation>Nie działa</translation>
    </message>
    <message>
        <source>Copy tracker URL</source>
        <translation>Kopiuj adres URL trackera</translation>
    </message>
    <message>
        <source>Add a new tracker...</source>
        <translation>Dodaj nowy tracker...</translation>
    </message>
    <message>
        <source>Edit tracker URL...</source>
        <translation>Edytuj adres URL trackera...</translation>
    </message>
    <message>
        <source>Tracker editing</source>
        <translation>Edytowanie trackera</translation>
    </message>
    <message>
        <source>Leeches</source>
        <translation>Pijawki</translation>
    </message>
    <message>
        <source>Remove tracker</source>
        <translation>Usuń tracker</translation>
    </message>
</context>
<context>
    <name>TrackersAdditionDialog</name>
    <message>
        <source>Trackers addition dialog</source>
        <translation>Dodawanie trackerów</translation>
    </message>
    <message>
        <source>List of trackers to add (one per line):</source>
        <translation>Lista trackerów do dodania (po jednym w wierszu):</translation>
    </message>
</context>
<context>
    <name>TransferListDelegate</name>
    <message>
        <source>%1 ago</source>
        <comment>e.g.: 1h 20m ago</comment>
        <translation>%1 temu</translation>
    </message>
    <message>
        <source>Allocating</source>
        <translation>Alokowanie</translation>
    </message>
    <message>
        <source>Paused</source>
        <translation>Wstrzymano</translation>
    </message>
    <message>
        <source>Completed</source>
        <translation>Ukończono</translation>
    </message>
    <message>
        <source>Moving</source>
        <translation>Przenoszenie</translation>
    </message>
    <message>
        <source>[F] Seeding</source>
        <translation>[W] Seedowanie</translation>
    </message>
    <message>
        <source>Seeding</source>
        <translation>Seedowanie</translation>
    </message>
    <message>
        <source>Queued</source>
        <translation>W kolejce</translation>
    </message>
    <message>
        <source>Errored</source>
        <translation>Błędne</translation>
    </message>
    <message>
        <source>[F] Downloading</source>
        <translation>[W] Pobieranie</translation>
    </message>
    <message>
        <source>Downloading metadata</source>
        <translation>Pobieranie metadanych</translation>
    </message>
    <message>
        <source>Checking</source>
        <translation>Sprawdzanie</translation>
    </message>
    <message>
        <source>Missing Files</source>
        <translation>Brakujące pliki</translation>
    </message>
    <message>
        <source>Queued for checking</source>
        <translation>W kolejce do sprawdzenia</translation>
    </message>
    <message>
        <source>Downloading</source>
        <translation>Pobieranie</translation>
    </message>
    <message>
        <source>Checking resume data</source>
        <translation>Sprawdzanie danych wznawiania</translation>
    </message>
    <message>
        <source>Stalled</source>
        <translation>Oczekujący</translation>
    </message>
</context>
<context>
    <name>TransferListFiltersWidget</name>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Categories</source>
        <translation>Kategorie</translation>
    </message>
</context>
<context>
    <name>TransferListWidget</name>
    <message>
        <source>Torrent Download Speed Limiting</source>
        <translation>Limitowanie prędkości pobierania torrenta</translation>
    </message>
    <message>
        <source>Torrent Upload Speed Limiting</source>
        <translation>Limitowanie prędkości wysyłania torrenta</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Zmień nazwę</translation>
    </message>
    <message>
        <source>Resume</source>
        <comment>Resume/start the torrent</comment>
        <translation>Wznów</translation>
    </message>
    <message>
        <source>Force Resume</source>
        <comment>Force Resume/start the torrent</comment>
        <translation>Wymuś wznowienie</translation>
    </message>
    <message>
        <source>Pause</source>
        <comment>Pause the torrent</comment>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>Delete the torrent</comment>
        <translation>Usuń</translation>
    </message>
    <message>
        <source>Limit share ratio...</source>
        <translation>Limituj współczynnik udziału...</translation>
    </message>
    <message>
        <source>Limit upload rate...</source>
        <translation>Limituj prędkości wysyłania...</translation>
    </message>
    <message>
        <source>Limit download rate...</source>
        <translation>Limituj prędkości pobierania...</translation>
    </message>
    <message>
        <source>Move up</source>
        <comment>i.e. move up in the queue</comment>
        <translation>Przenieś w górę</translation>
    </message>
    <message>
        <source>Move down</source>
        <comment>i.e. Move down in the queue</comment>
        <translation>Przenieś w dół</translation>
    </message>
    <message>
        <source>Move to top</source>
        <comment>i.e. Move to top of the queue</comment>
        <translation>Przenieś na początek</translation>
    </message>
    <message>
        <source>Move to bottom</source>
        <comment>i.e. Move to bottom of the queue</comment>
        <translation>Przenieś na koniec</translation>
    </message>
    <message>
        <source>Set location...</source>
        <translation>Ustaw położenie...</translation>
    </message>
    <message>
        <source>Copy name</source>
        <translation>Kopiuj nazwę</translation>
    </message>
    <message>
        <source>Copy hash</source>
        <translation>Kopiuj hash</translation>
    </message>
    <message>
        <source>Download first and last pieces first</source>
        <translation>Pobierz najpierw część pierwszą i ostatnią</translation>
    </message>
    <message>
        <source>Automatic Torrent Management</source>
        <translation>Automatyczne zarządzanie torrentem</translation>
    </message>
    <message>
        <source>Category</source>
        <translation>Kategoria</translation>
    </message>
    <message>
        <source>New...</source>
        <comment>New category...</comment>
        <translation>Nowa...</translation>
    </message>
    <message>
        <source>Reset</source>
        <comment>Reset category</comment>
        <translation>Resetuj</translation>
    </message>
    <message>
        <source>Priority</source>
        <translation>Priorytet</translation>
    </message>
    <message>
        <source>Force recheck</source>
        <translation>Sprawdź pobrane dane</translation>
    </message>
    <message>
        <source>Copy magnet link</source>
        <translation>Kopiuj odnośnik magnet</translation>
    </message>
    <message>
        <source>Super seeding mode</source>
        <translation>Tryb super-seeding</translation>
    </message>
    <message>
        <source>Rename...</source>
        <translation>Zmień nazwę...</translation>
    </message>
    <message>
        <source>Download in sequential order</source>
        <translation>Pobierz w kolejności sekwencyjnej</translation>
    </message>
    <message>
        <source>Force Recheck</source>
        <translation>Wymuś ponowne sprawdzenie</translation>
    </message>
    <message>
        <source>New Category</source>
        <translation>Nowa kategoria</translation>
    </message>
    <message>
        <source>Location</source>
        <translation>Błąd położenia</translation>
    </message>
    <message>
        <source>New name</source>
        <translation>Nowa nazwa</translation>
    </message>
    <message>
        <source>Set location</source>
        <translation>Ustaw położenie</translation>
    </message>
    <message>
        <source>Force reannounce</source>
        <translation>Wymuś rozgłoszenie</translation>
    </message>
    <message>
        <source>Edit Category</source>
        <translation>Edytuj kategorię</translation>
    </message>
    <message>
        <source>Save path</source>
        <translation>Ścieżka zapisu</translation>
    </message>
</context>
<context>
    <name>UpDownRatioDialog</name>
    <message>
        <source>Torrent Upload/Download Ratio Limiting</source>
        <translation>Limitowanie współczynnika wysyłania i pobierania torrenta</translation>
    </message>
    <message>
        <source>Use global share limit</source>
        <translation>Użyj globalnego limitu udziału</translation>
    </message>
    <message>
        <source>Set no share limit</source>
        <translation>Ustaw bez limitu udziału</translation>
    </message>
    <message>
        <source>Set share limit to</source>
        <translation>Ustaw limit udziału na</translation>
    </message>
    <message>
        <source>ratio</source>
        <translation>udział</translation>
    </message>
    <message>
        <source>minutes</source>
        <translation>minuty</translation>
    </message>
</context>
<context>
    <name>about</name>
    <message>
        <source>An advanced BitTorrent client programmed in C++, based on Qt toolkit and libtorrent-rasterbar.</source>
        <translation>Zaawansowany klient BitTorrent napisany w języku C++ z wykorzystaniem bibliotek Qt i libtorrent-rasterbar.</translation>
    </message>
    <message>
        <source>Home Page:</source>
        <translation>Strona domowa:</translation>
    </message>
    <message>
        <source>Forum:</source>
        <translation>Forum:</translation>
    </message>
    <message>
        <source>Bug Tracker:</source>
        <translation>Śledzenie błędów:</translation>
    </message>
</context>
<context>
    <name>confirmDeletionDlg</name>
    <message>
        <source>Deletion confirmation</source>
        <translation>Potwierdzenie usuwania</translation>
    </message>
    <message>
        <source>Also delete the files on the hard disk</source>
        <translation>Usuń także dane z twardego dysku</translation>
    </message>
    <message>
        <source>Deletion confirmation - qBittorrent</source>
        <translation>Potwierdzenia usuwania - qBittorrent</translation>
    </message>
</context>
<context>
    <name>downloadFromURL</name>
    <message>
        <source>Download from URLs</source>
        <translation>Pobierz z adresów URL</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Add Torrent Links</source>
        <translation>Dodaj łącza torrenta</translation>
    </message>
</context>
<context>
    <name>misc</name>
    <message>
        <source>B</source>
        <comment>bytes</comment>
        <translation>B</translation>
    </message>
    <message>
        <source>KiB</source>
        <comment>kibibytes (1024 bytes)</comment>
        <translation>KiB</translation>
    </message>
    <message>
        <source>MiB</source>
        <comment>mebibytes (1024 kibibytes)</comment>
        <translation>MiB</translation>
    </message>
    <message>
        <source>GiB</source>
        <comment>gibibytes (1024 mibibytes)</comment>
        <translation>GiB</translation>
    </message>
    <message>
        <source>TiB</source>
        <comment>tebibytes (1024 gibibytes)</comment>
        <translation>TiB</translation>
    </message>
    <message>
        <source>PiB</source>
        <comment>pebibytes (1024 tebibytes)</comment>
        <translation>PiB</translation>
    </message>
    <message>
        <source>EiB</source>
        <comment>exbibytes (1024 pebibytes)</comment>
        <translation>EiB</translation>
    </message>
    <message>
        <source>/s</source>
        <comment>per second</comment>
        <translation>/s</translation>
    </message>
    <message>
        <source>%1h %2m</source>
        <comment>e.g: 3hours 5minutes</comment>
        <translation>%1h %2m</translation>
    </message>
    <message>
        <source>%1d %2h</source>
        <comment>e.g: 2days 10hours</comment>
        <translation>%1d %2h</translation>
    </message>
    <message>
        <source>Unknown</source>
        <comment>Unknown (size)</comment>
        <translation>Nieznany</translation>
    </message>
    <message>
        <source>&lt; 1m</source>
        <comment>&lt; 1 minute</comment>
        <translation>&lt; 1m</translation>
    </message>
    <message>
        <source>%1m</source>
        <comment>e.g: 10minutes</comment>
        <translation>%1m</translation>
    </message>
</context>
<context>
    <name>TorrentsController</name>
    <message>
        <source>Save path is empty</source>
        <translation>Ścieżka zapisu jest pusta</translation>
    </message>
</context>
<context>
    <name>PluginSourceDlg</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>Plugin path:</source>
        <translation>Ścieżka wtyczki:</translation>
    </message>
    <message>
        <source>URL or local directory</source>
        <translation>Adres URL albo katalog lokalny</translation>
    </message>
    <message>
        <source>Install plugin</source>
        <translation>Zainstaluj wtyczkę</translation>
    </message>
    <message>
        <source>Ok</source>
        <translation>OK</translation>
    </message>
</context>
<context>
    <name>SearchEngineWidget</name>
    <message>
        <source>Seeds:</source>
        <translation>Seedy:</translation>
    </message>
    <message>
        <source>All plugins</source>
        <translation>Wszystkie wtyczki</translation>
    </message>
    <message>
        <source>Size:</source>
        <translation>Rozmiar:</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>Zatrzymaj</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Szukaj</translation>
    </message>
    <message>
        <source>Search plugins...</source>
        <translation>Wtyczki wyszukiwania...</translation>
    </message>
    <message>
        <source>All categories</source>
        <translation>Wszystkie kategorie</translation>
    </message>
    <message>
        <source>Search in:</source>
        <translation>Wyszukaj w:</translation>
    </message>
    <message>
        <source>Copy description page URL</source>
        <translation>Kopiuj adres URL strony z opisem</translation>
    </message>
    <message>
        <source>Go to description page</source>
        <translation>Przejdź do strony z opisem</translation>
    </message>
    <message>
        <source>Results (showing</source>
        <translation>Wyniki (pokazanie</translation>
    </message>
    <message>
        <source>Download</source>
        <translation>Pobierz</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtr</translation>
    </message>
    <message>
        <source>Torrent names only</source>
        <translation>Tylko nazwy torrentów</translation>
    </message>
    <message>
        <source>Only enabled</source>
        <translation>Tylko włączone</translation>
    </message>
    <message>
        <source>out of</source>
        <translation>z</translation>
    </message>
    <message>
        <source>Everywhere</source>
        <translation>Wszędzie</translation>
    </message>
</context>
<context>
    <name>PluginSelectDlg</name>
    <message>
        <source>Uninstall</source>
        <translation>Odinstaluj</translation>
    </message>
    <message>
        <source>Install new plugin</source>
        <translation>Zainstaluj nową wtyczkę</translation>
    </message>
    <message>
        <source>You can get new search engine plugins here:</source>
        <translation>Tutaj możesz pobrać nowe wtyczki wyszukiwania:</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Installed search plugins:</source>
        <translation>Zainstalowane wtyczki wyszukiwania:</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Włączone</translation>
    </message>
    <message>
        <source>Warning: Be sure to comply with your country's copyright laws when downloading torrents from any of these search engines.</source>
        <translation>Ostrzeżenie: upewnij się, że przestrzegasz praw autorskich swojego kraju podczas pobierania torrentów z każdej z tych wyszukiwarek.</translation>
    </message>
    <message>
        <source>Check for updates</source>
        <translation>Sprawdź aktualizacje</translation>
    </message>
    <message>
        <source>Search plugins</source>
        <translation>Wtyczki wyszukiwania</translation>
    </message>
</context>
<context>
    <name>SearchResultsTable</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Size</source>
        <translation>Rozmiar</translation>
    </message>
    <message>
        <source>Leechers</source>
        <translation>Pijawki</translation>
    </message>
    <message>
        <source>Search engine</source>
        <translation>Wyszukiwarka</translation>
    </message>
    <message>
        <source>Seeders</source>
        <translation>Seedujący</translation>
    </message>
</context>
<context>
    <name>SearchPluginsTable</name>
    <message>
        <source>Name</source>
        <translation>Nazwa</translation>
    </message>
    <message>
        <source>Url</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Enabled</source>
        <translation>Włączone</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Wersja</translation>
    </message>
</context>
</TS>